AlwaysAuthenticatedPolicy class
A DeepLinkAuthenticationPolicy that always reports the user as authenticated.
Use this for apps that do not have a login flow, or during development when you want to skip authentication gating.
- Implemented types
Constructors
- AlwaysAuthenticatedPolicy()
-
Creates an AlwaysAuthenticatedPolicy.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
Always returns
true.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited